@@ -1,10 +1,9 @@
-id = desiteThis.ID()
-pset = "Allgemeine_Eigenschaften:"
-ident_attrib = "bauteilKlassifikation"
+﻿id = desiteThis.ID();
+pset = "Allgemeine_Eigenschaften:";
+ident_attrib = "bauteilKlassifikation";
 
-status = desiteAPI.getPropertyValue(id, "Check_State", "xs:string")
-objekttyp = desiteAPI.getPropertyValue(id, pset + ident_attrib, "xs:string")
-console.log(status)
+status = desiteAPI.getPropertyValue(id, "Check_State", "xs:string");
+objekttyp = desiteAPI.getPropertyValue(id, pset + ident_attrib, "xs:string");
 
 if (status == "Ungeprüft") {
     desiteResult.setCheckState('failed');
