@@ -241,7 +241,7 @@ class ExcelBlock(metaclass=ExcelIterator):
         return set(string_list)
 
 
-def open_file(path: str) -> None:
+def open_file(path: str,ws_name:str) -> None:
     # TODO: add request for Identification Attribute
 
     def create_blocks() -> None:
@@ -338,7 +338,10 @@ def open_file(path: str) -> None:
         new_path = os.path.join(tmpdirname, "excel.xlsx")
         shutil.copy2(path, new_path)
         book = openpyxl.load_workbook(new_path)
-        sheet = book.active
+        if ws_name not in book.sheetnames:
+            logging.error("Worksheet Name not in Workbook")
+            return
+        sheet = book[ws_name]
 
         create_blocks()
         create_items()
